#!/bin/ksh

### GAD PIPELINE ###
## count_reads.sh
## Version : 2.4.0
## Description : This script allows user to launch HTseq-count command
## Usage : qsub -pe smp 1 -v INPUTFILE=</path/to/the/input/file>,OUTPUTFILE=</path/to/the/output/file>,[STRANDED=yes|no],[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] count_reads.sh
## Output : tabulated output file with read count for each gene
## Requirements : python 2.7, HTseq-count

## Author : Emilie.Tisserant@u-bourgogne.fr
## Creation Date : 20170104
## last revision date : 20170104
## Known bugs : None

#$ -q batch
#$ -V


# Log file path option
if [ -z ${LOGFILE} ]
then
    LOGFILE=count_reads.$(date +"%F_%H-%M-%S").log
fi

# Config file path option
if [ -z ${CONFIGFILE} ]
then
    CONFIGFILE=analysis_config.tsv
fi


PYTHONBIN=$(grep "pythonbin" $CONFIGFILE | awk '{print $2}')
REFSEQGTF=$(grep "hg19gtf" $CONFIGFILE | awk '{print $2}')


# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if config file exist
if [ ! -f $CONFIGFILE ]
then
    echo "Config file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch count_reads.failed
    exit 1
fi

# Check if input file exist
if [ ! -f $INPUTFILE ]
then
    echo "Input file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch count_reads.failed
    exit 1
fi

# Check if output file is specified
if [ -z $OUTPUTFILE ]
then
    echo "Output file is not specified"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch count_reads.failed
    exit 1
fi

# Check stranded option
if [ -z $STRANDED ]
then
    STRANDED="yes"
fi

# Launch HTseq-count command and check exit code
echo "Command: $PYTHONBIN -m HTSeq.scripts.count -f bam -r name -s $STRANDED $INPUTFILE $REFSEQGTF > $OUTPUTFILE"
$PYTHONBIN -m HTSeq.scripts.count -f bam -r name -s $STRANDED $INPUTFILE $REFSEQGTF > $OUTPUTFILE
countreads_exitcode=$?
echo "HTseq-count exit code : $countreads_exitcode"
if [ $countreads_exitcode != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch count_reads.failed
    exit 1
fi

echo "$(date +"%F_%H-%M-%S"): END"
