#!/bin/ksh

### GAD PIPELINE ###
## create_design.sh
## Description : This script create a design file based on the batch analysis
## Usage : qsub -pe smp 1 -v INPUTDIR=</path/to/the/input/dir>,[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] create_design.sh
## Output : tabulated output file with read count for each gene
## Requirements : GAD pipeline directory structure

## Author : yannis.duffourd@u-bourgogne.fr
## Creation Date : 20200929
## last revision date : 20200929
## Known bugs : None

#$ -q batch
#$ -pe smp 1
#$ -V


# Log file path option
if [ -z ${LOGFILE} ]
then
    LOGFILE=create_design.$(date +"%F_%H-%M-%S").log
fi

# Config file path option
if [ -z ${CONFIGFILE} ]
then
    CONFIGFILE=analysis_config.tsv
fi

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if config file exist
if [ ! -f $CONFIGFILE ]
then
    echo "Config file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch create_design.failed
    exit 1
fi

# Check if input dir exist
if [ -z ${INPUTDIR} ]
then
    echo "Input Directory does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch create_design.failed
    exit 1
fi

# list of samples
samples=`find $INPUTDIR -maxdepth 1 -mindepth 1 -type d -exec basename {} \;`

# manage a design file for each sample detected
# the design is simple : 1 vs all other
for currentSample in $samples
do
	# rewrite a new design file
	echo "$currentSample\tsample" > $INPUTDIR/$currentSample/$currentSample.DE.design.tsv

	# all the other sample in the batch are LOcontrols
	for tmpSample in $samples
	do
		if [ "$currentSample" != "$tmpSample" ]
		then
			echo "$tmpSample\tcontrol" >> $INPUTDIR/$currentSample/$currentSample.DE.design.tsv
		fi
	done
done

createdesign_exitcode=$?
echo "Create design exit code : $createdesign_exitcode"

if [ $createdesign_exitcode != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch create_design.failed
    exit 1
fi

echo "$(date +"%F_%H-%M-%S"): END"
