#!/bin/ksh

### GAD PIPELINE ###
## clean_bam.sh
## Version : 2.4.0
## Description : This script allows user to launch Picard CleanSam command
## Usage : qsub -pe smp 1 -v INPUTFILE=</path/to/the/input/file>,OUTPUTFILE=</path/to/the/output/file>,[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] clean_bam.sh
## Output : Clean BAM output file
## Requirements : jdk 1.7.0, Picard 1.109

## Author : Emilie.Tisserant@u-bourgogne.fr
## Creation Date : 20150624
## last revision date : 20150818
## Known bugs : None

#$ -q batch
#$ -V

# Log file path option
if [ -z ${LOGFILE} ]
then
    LOGFILE=clean_bam.$(date +"%F_%H-%M-%S").log
fi

# Config file path option
if [ -z ${CONFIGFILE} ]
then
    CONFIGFILE=analysis_config.tsv
fi

JAVA=$(grep "javacmd" $CONFIGFILE | awk '{print $2" "$3}')
PICARD=$(grep "picardbase" $CONFIGFILE | awk '{print $2}')
TEMPORARY_DIR=$(grep "temporary_dir" $CONFIGFILE | awk '{print $2}')

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if config file exist
if [ ! -f $CONFIGFILE ]
then
    echo "Config file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch clean_bam.failed
    exit 1
fi

# Check if input file exist
if [ ! -f $INPUTFILE ]
then
    echo "Input file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch clean_bam.failed
    exit 1
fi

# Check if output file is specified
if [ -z $OUTPUTFILE ]
then
    echo "Output file is not specified"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch clean_bam.failed
    exit 1
fi

# Launch Picard CleanSam command and check exit code
echo "Picard command: $JAVA -Djava.io.tmpdir=$TEMPORARY_DIR -Xmx8g -jar $PICARD/picard.jar CleanSam INPUT=$INPUTFILE OUTPUT=$OUTPUTFILE TMP_DIR=$TEMPORARY_DIR"
$JAVA -Djava.io.tmpdir=$TEMPORARY_DIR -Xmx8g -jar $PICARD/picard.jar CleanSam INPUT=$INPUTFILE OUTPUT=$OUTPUTFILE TMP_DIR=$TEMPORARY_DIR
cleansam_exitcode=$?
echo "CleanSam exit code : $cleansam_exitcode"
if [ $cleansam_exitcode != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch clean_bam.failed
    exit 1
fi

echo "$(date +"%F_%H-%M-%S"): END"

