#!/bin/bash

### GAD PIPELINE ###
## split_cigar_reads.sh
## Version : 2.4.1
## Description : This script allows user to split reads aligned on multiple exons in a bam file. Mainly used in RNASeq. 
## Usage : qsub -pe smp 1 -v INPUTFILE=</path/to/the/input/file>,OUTPUTFILE=</path/to/the/output/file>,[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] split_cigar_reads.sh
## Output : BAM file
## Requirements : GATK 3.7

## Author : yannis.duffourd@u-bourgogne.fr
## Creation Date : 20170327
## last revision date : 20170327
## Known bugs : None

#$ -q batch
#$ -V

# Log file path option
if [ -z ${LOGFILE} ]
then
    LOGFILE=split_cigar_reads.$(date +"%F_%H-%M-%S").log
fi
exec 1>> $LOGFILE 2>&1
# Config file path option
if [ -z ${CONFIGFILE} ]
then
    CONFIGFILE=analysis_config.tsv
fi

JAVA=$(grep "javacmd" $CONFIGFILE | awk '{print $2" "$3}')
GATK=$(grep "GATKbase" $CONFIGFILE | awk '{print $2}')
TEMPORARY_DIR=$(grep "temporary_dir" $CONFIGFILE | awk '{print $2}')
REF=$(grep "reference" $CONFIGFILE | awk '{print $2}')



# Launch GATK SplitNCigarReads and check exit code
echo "Command : $JAVA -jar -Djava.io.tmpdir=$TEMPORARY_DIR -Xmx16g $GATK/GenomeAnalysisTK.jar -T SplitNCigarReads -I $INPUTFILE -R $REF -o $OUTPUTFILE -rf ReassignOneMappingQuality -RMQF 255 -RMQT 60 -U ALLOW_N_CIGAR_READS -rf BadCigar  -filterRNC"
$JAVA -jar -Djava.io.tmpdir=$TEMPORARY_DIR -Xmx16g $GATK/GenomeAnalysisTK.jar -T SplitNCigarReads -I $INPUTFILE -R $REF -o $OUTPUTFILE -rf ReassignOneMappingQuality -RMQF 255 -RMQT 60 -U ALLOW_N_CIGAR_READS -rf BadCigar -filterRNC
splitNtrim_exitcode=$?
echo "splitNTrim exit code : $splitNtrim_exitcode"
if [ $splitNtrim_exitcode != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch splitNtrim.failed
    exit 1
fi



