#!/bin/ksh

### GAD PIPELINE ###
## compile_rnaseq_preprocessing_status.sh
## Version : 2.4.0
## Description : ccompile status for a rnaseq preprocessing analysis batch
## Usage : qsub -v ANALYSISDIR=</path/to/the/analysis/dir>[LOGFILE=</path/to/the/log/file>][STATUSFILE=</path/to/the/status/file>] compile_rnaseq_preprocessing_status.sh
## Output : A tabulated file with the status of each steps of the rnaseq preprocessing for the current batch
## Requirements : None

## Author : yannis.duffourd@u-bourgogne.fr
## Creation Date : 2017037
## Last revision date : 20170327
## Known bugs : None.

#$ -q batch
#$ -V

# LOG OPTION
if [ -z ${LOGFILE+x} ]
then
  LOGFILE="compile_preprocessing_statut.$(date +"%F_%H-%M-%S").log"
fi

# Logging
exec 1>> $LOGFILE 2>&1

echo "Starting compile_preprocessing_statut.sh at $(date +"%F_%H-%M-%S")"

# mandatory arguments
if [ -z ${ANALYSISDIR} ]
then
    echo "ANALYSISDIR was not defined : execution stopped"
    exit 1
fi

if [ -z ${STATUSFILE+x} ]
then
  STATUSFILE="status.tsv"
fi

echo "$(date): START"

# if file already exists, delete it.
if [ -e "$STATUSFILE" ]
then
    echo "Command : rm -f $STATUSFILE"
    rm -f $STATUSFILE
fi

# check rename
if [ -e "$ANALYSISDIR/rename_raw.failed" ]
then
    echo "rename_raw	FAIL" > $STATUSFILE
else
    echo "rename_raw	PASS" > $STATUSFILE
fi

# check organize
if [ -e "$ANALYSISDIR/organize_data_folder.failed" ]
then
    echo "organize_data_folder	FAIL" >> $STATUSFILE
else
    echo "organize_data_folder	PASS" >> $STATUSFILE
fi

# fastqc
if [ -e "$ANALYSISDIR/process_fastqc.failed" ]
then
    echo "process_fastqc	FAIL" >> $STATUSFILE
else
    echo "process_fastqc	PASS" >> $STATUSFILE
fi

# trim
if [ -e "$ANALYSISDIR/trim_fastq.failed" ]
then
    echo "trim_fastq	FAIL" >> $STATUSFILE
else
    echo "trim_fastq	PASS" >> $STATUSFILE
fi

# aln
if [ -e "$ANALYSISDIR/star2_alignement.failed" ]
then
    echo "align_star2	FAIL" >> $STATUSFILE
else
    echo "align_star2	PASS" >> $STATUSFILE
fi

# sam to bam & sort
if [ -e "$ANALYSISDIR/sort_bam.failed" ]
then
    echo "sort_bam	FAIL" >> $STATUSFILE
else
    echo "sort_bam	PASS" >> $STATUSFILE
fi

# clean bam
if [ -e "$ANALYSISDIR/clean_bam.failed" ]
then
    echo "clean_bam	FAIL" >> $STATUSFILE
else
    echo "clean_bam	PASS" >> $STATUSFILE
fi

# add rg to bam
if [ -e "$ANALYSISDIR/add_readgroups.failed" ]
then
    echo "add_rg	FAIL" >> $STATUSFILE
else
    echo "add_rg	PASS" >> $STATUSFILE
fi

# Mark duplicates
if [ -e "$ANALYSISDIR/mark_duplicates.failed" ]
then
    echo "mark_duplicates	FAIL" >> $STATUSFILE
else
    echo "mark_duplicates	PASS" >> $STATUSFILE
fi

# split and trim
if [ -e "$ANALYSISDIR/splitNtrim.failed" ]
then
    echo "split_trim	FAIL" >> $STATUSFILE
else
    echo "split_trim	PASS" >> $STATUSFILE
fi

# recalibrate scores
if [ -e "$ANALYSISDIR/recal_bam.failed" ]
then
    echo "recal_bam	FAIL" >> $STATUSFILE
else
    echo "recal_bam	PASS" >> $STATUSFILE
fi

# matrix
if [ -e "$ANALYSISDIR/wrapper_list_counts.failed" ] || [ -e "$ANALYSISDIR/create_counts_matrix.failed" ]
then
    echo "matrix	FAIL" >> $STATUSFILE
else
    echo "matrix	PASS" >> $STATUSFILE
fi

# DE
if [ -e "$ANALYSISDIR/run_de_analysis.failed" ]
then
    echo "DE	FAIL" >> $STATUSFILE
else
    echo "DE	PASS" >> $STATUSFILE
fi

echo "compile_preprocessing_status ends with status $? at "$(date +"%F_%H-%M-%S")
