#!/bin/bash

### GAD PIPELINE ###
## wrapper_annotation_SJ_with_genes.sh
## Description : wrapper for annotate a SJ file with data from refseq genes
## Usage : qsub -v INPUTFILE=</path/to/the/input/SJ/file>,OUTPUTFILE=</path/to/the/output/annotated/SJ/file>,[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] wrapper_annotate_SJ_with_genes.sh
## Output : a tabulated SJ file containing genes annotation
## Requirements : python 2.7

## Author : emilie.tisserant@u-bourgogne.fr, yannis.duffourd@u-bourgogne.fr
## Creation Date : 20180417
## last revision date : 20201009
## Known bugs : None

#$ -V
#$ -q batch



# logfile
if [ -z ${LOGFILE} ]
then
    LOGFILE=annotate_SJ_with_genes.$(date +"%F_%H-%M-%S").log
fi

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if input file exist
if [ ! -f $INPUTFILE ]
then
    echo "Input file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch annotate_SJ_with_genes.failed
    exit 1
fi

# Config file path option
if [ -z ${CONFIGFILE} ]
then
   CONFIGFILE=analysis_config.tsv
fi


PYTHONBIN=$(grep "pythonbin" $CONFIGFILE | awk '{print $2}')
PIPELINEBASE=$(grep "pipelinebase" $CONFIGFILE | cut -f2)
REFSEQ=$(grep "leafcutterannot" $CONFIGFILE | awk '{print $2}')


# TODO path
echo "Command : $PYTHONBIN $PIPELINEBASE/common/splice/annotate_SJ_with_genes.py -i $INPUTFILE -g $REFSEQ -o $OUTPUTFILE"
$PYTHONBIN $PIPELINEBASE/common/splice/annotate_SJ_with_genes.py -i $INPUTFILE -g $REFSEQ -o $OUTPUTFILE
exit_code=$?
echo "wrapper_annotate_SJ_with_genes.sh exit code : $exit_code"
if [ $exit_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch annotate_SJ_with_genes.failed
    exit 1
fi


echo "$(date +"%F_%H-%M-%S"): END"
