#!/bin/bash

### GAD PIPELINE ###
## wrapper_intron_clustering.sh
## Description : clustering of leafcutter junctions
## Usage : qsub -v INPUTDIR=<analysis directory>,OUTPUT=<output_prefix>,[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] wrapper_intron_clustering.sh
## Output : 1 cluster file for all samples
## Requirements : Leafcutter, python 2.x

## Author : emilie.tisserant@u-bourgogne.fr, yannis.duffourd@u-bourgogne.fr
## Creation Date : 20180417
## last revision date : 20200929
## Known bugs : None

#$ -V
#$ -q batch
#$ -pe smp 1

# logfile
if [ -z ${LOGFILE} ]
then
    LOGFILE=intron_clustering.$(date +"%F_%H-%M-%S").log
fi

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if input directory exist
if [ -z $INPUTDIR ]
then
    echo "Input directory does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch intron_clustering.failed
    exit 1
fi

# Check if output file is specified
if [ -z $OUTPUTFILE ]
then
    echo "Output file is not specified"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch intron_clustering.failed
    exit 1
fi

# Config file path option
if [ -z ${CONFIGFILE} ]
then
    CONFIGFILE=analysis_config.tsv
fi

SAMTOOLSDIR=$(grep "samtools" $CONFIGFILE | awk '{print $2}')
leafCutterDir=$(grep "leafcutterdir" $CONFIGFILE | awk '{print $2}')
PYTHONBIN=$(grep "pythonbin" $CONFIGFILE | awk '{print $2}')

# regroupe all junc file in a list
echo "Command : ls -1 $INPUTDIR/*/*.junc > $INPUTDIR/all.junc.files.tsv"
ls -1 $INPUTDIR/*/*.junc > $INPUTDIR/all.junc.files.tsv

echo "Command : $PYTHONBIN $leafCutterDir/clustering/leafcutter_cluster.py -j $INPUTDIR/all.junc.files.tsv -r $INPUTDIR -m 50 -o $OUTPUTFILE -l 500000"
$PYTHONBIN $leafCutterDir/clustering/leafcutter_cluster.py -j $INPUTDIR/all.junc.files.tsv -r $INPUTDIR -m 50 -o $OUTPUTFILE -l 500000
exit_code=$?
echo "wrapper_intron_clustering.sh exit code : $exit_code"

if [ $exit_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch intron_clustering.failed
    exit 1
fi

echo "$(date +"%F_%H-%M-%S"): END"
